==> ownCloud-5.3.2.15463.tar.xz: ownCloud-5.3.2.15463/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the ownCloud Desktop Client, please
join our [rocket chat channel][rocketchat] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines
* __Important__: When reporting an issue provide as much requested information as possible, we :heart: log files.
* __SECURITY__: Report any potential security bug to security@owncloud.com following our [security policy](https://owncloud.com/security/) instead of filing an issue in our bug tracker
* This repository is *only* for issues within the ownCloud desktop client. 
  Issues in other components should be reported in their own repositores: 
  - [ownCloud server](https://github.com/owncloud/core/issues)
  - [ownCloud apps](https://github.com/owncloud/apps/issues) (e.g. Calendar,
    Contacts...)
  - [Android client](https://github.com/owncloud/android/issues)
  - [iOS client](https://github.com/owncloud/ios-issues/issues)
* Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[rocketchat]: https://talk.owncloud.com/channel/desktop
[forum]: https://central.owncloud.org/
[irc]: https://web.libera.chat/?channels=#owncloud

## Contributing to Source Code

Thanks for wanting to contribute source code to ownCloud. That's great!

Before we're able to merge your code to ownCloud Desktop Client, you need to sign
our [Contributor Agreement][agreement].

Please read the [Desktop Client Manual][desktopman] and the [Developer
Manuals][devmanual] to get useful info like how to create your first
application or how to test the ownCloud code with phpunit.

[agreement]: https://owncloud.com/contribute/join-the-development/contributor-agreement/
[devmanual]: https://doc.owncloud.com/desktop/latest/appendices/building.html
[desktopman]: https://doc.owncloud.com/desktop

## Translations
Please submit translations via [Transifex][transifex].

[transifex]: https://www.transifex.com/projects/p/owncloud/

==> ownCloud-6.0.3.18040.tar.xz: ownCloud-6.0.3.18040/CONTRIBUTING.md <==
## Submitting Desktop Client issues

If you have questions about how to use the ownCloud Desktop Client, please
join our [rocket chat channel][rocketchat] or our [forum][forum].
We are also available on [IRC][irc].

### Bug Reporting Guidelines

- **Important**: When reporting an issue provide as much requested information as possible, we :heart: log files.
- **SECURITY**: Report any potential security bug to security@owncloud.com following our [security policy](https://owncloud.com/security/) instead of filing an issue in our bug tracker
- This repository is _only_ for issues within the ownCloud desktop client.
  Issues in other components should be reported in their own repositories:
  - [ownCloud server](https://github.com/owncloud/core/issues)
  - [ownCloud apps](https://github.com/owncloud/apps/issues) (e.g. Calendar,
    Contacts...)
  - [Android client](https://github.com/owncloud/android/issues)
  - [iOS client](https://github.com/owncloud/ios-issues/issues)
- Search the existing issues first, it's likely that your issue was already
  reported.

If your issue appears to be a bug, and hasn't been reported, open a new issue.

Help us to maximize the effort we can spend fixing issues and adding new
features, by not reporting duplicate issues.

[rocketchat]: https://talk.owncloud.com/channel/desktop
[forum]: https://central.owncloud.org/
[irc]: https://web.libera.chat/?channels=#owncloud

## Contributing to Source Code

Thanks for wanting to contribute source code to ownCloud. That's great!

Before we're able to merge your code to ownCloud Desktop Client, you need to sign
our [Contributor Agreement][agreement].

Please read the [Desktop Client Manual][desktopman] to get useful info about the client.

[agreement]: https://owncloud.com/contribute/join-the-development/contributor-agreement/
[desktopman]: https://doc.owncloud.com/desktop

## Translations

Please submit translations via [Transifex][transifex].

[transifex]: https://www.transifex.com/projects/p/owncloud/
